ProSHADE: src/proshade/ProSHADE_io.hpp File Reference

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Namespaces | Enumerations | Functions
ProSHADE_io.hpp File Reference

This header file declares all the functions required for low level file format access. More...

`#include "ProSHADE_settings.hpp"`

Go to the source code of this file.

## Namespaces
| ProSHADE_internal_io
| This namespace contains the internal input/output functions. None of these should be directly accessed by the user.

## Enumerations
enum | InputType { UNKNOWN, PDB, MAP }

## Functions
InputType | ProSHADE_internal_io::figureDataType (std::string fName)
| Function determining input data type. More...
bool | ProSHADE_internal_io::isFilePDB (std::string fName)
| Function determining if the input data type is PDB. More...
bool | ProSHADE_internal_io::isFileMAP (std::string fName)
| Function determining if the input data type is MAP. More...
void | ProSHADE_internal_io::readInMapHeader (gemmi::Ccp4< float > *map, proshade_unsign *xDimInds, proshade_unsign *yDimInds, proshade_unsign *zDimInds, proshade_single *xDim, proshade_single *yDim, proshade_single *zDim, proshade_single *aAng, proshade_single *bAng, proshade_single *cAng, proshade_signed *xFrom, proshade_signed *yFrom, proshade_signed *zFrom, proshade_signed *xAxOrigin, proshade_signed *yAxOrigin, proshade_signed *zAxOrigin, proshade_unsign *xAxOrder, proshade_unsign *yAxOrder, proshade_unsign *zAxOrder, proshade_unsign *xGridInds, proshade_unsign *yGridInds, proshade_unsign *zGridInds)
| This function parses the CCP4 MAP file header as read in by gemmi. More...
void | ProSHADE_internal_io::readInMapData (gemmi::Ccp4< float > *gemmiMap, proshade_double *&map, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds, proshade_unsign xAxOrder, proshade_unsign yAxOrder, proshade_unsign zAxOrder)
| This function converts the gemmi Ccp4 object data to ProSHADE internal map representation. More...
void | ProSHADE_internal_io::writeOutMapHeader (gemmi::Ccp4< float > *map, proshade_unsign xDimInds, proshade_unsign yDimInds, proshade_unsign zDimInds, proshade_single xDim, proshade_single yDim, proshade_single zDim, proshade_single aAng, proshade_single bAng, proshade_single cAng, proshade_signed xFrom, proshade_signed yFrom, proshade_signed zFrom, proshade_signed xAxOrigin, proshade_signed yAxOrigin, proshade_signed zAxOrigin, proshade_unsign xAxOrder, proshade_unsign yAxOrder, proshade_unsign zAxOrder, proshade_unsign xGridInds, proshade_unsign yGridInds, proshade_unsign zGridInds, std::string title, int mode)
| This function parses the CCP4 MAP file header as read in by gemmi. More...
void | ProSHADE_internal_io::writeRotationTranslationJSON (proshade_double trsX1, proshade_double trsY1, proshade_double trsZ1, proshade_double eulA, proshade_double eulB, proshade_double eulG, proshade_double trsX2, proshade_double trsY2, proshade_double trsZ2, std::string fileName)
| Function for writing out the optimal rotation and translation into a JSON file. More...

## Detailed Description

This header file declares all the functions required for low level file format access.

This header file declares the ProSHADE_internal_io namespace, which groups together all the low level functions required for input and output file format detection, reading and writing. Also, most of the interactions with the Gemmi library are done by these functions as to avoid these being dispersed everywhere.

Copyright by Michal Tykac and individual contributors. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 1) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer. 2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 3) Neither the name of Michal Tykac nor the names of this code's contributors may be used to endorse or promote products derived from this software without specific prior written permission.

This software is provided by the copyright holder and contributors "as is" and any express or implied warranties, including, but not limitted to, the implied warranties of merchantibility and fitness for a particular purpose are disclaimed. In no event shall the copyright owner or the contributors be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, but not limitted to, procurement of substitute goods or services, loss of use, data or profits, or business interuption) however caused and on any theory of liability, whether in contract, strict liability or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damage.

Author
  Michal Tykac
  Garib N. Murshudov

Version
  0.7.5.1

Date
  JAN 2021

Definition in file ProSHADE_io.hpp.